;; Generated package description from websocket.el  -*- no-byte-compile: t -*-
(define-package "websocket" "1.16" "Emacs WebSocket client and server" '((cl-lib "0.5")) :commit "03d1cca4bd910a8df73e4ec637836c6ac25213a2" :authors '(("Andrew Hyatt" . "ahyatt@gmail.com")) :maintainer '("Andrew Hyatt" . "ahyatt@gmail.com") :keywords '("communication" "websocket" "server") :url "https://github.com/ahyatt/emacs-websocket")
